@@ -5,9 +5,10 @@
 # requires Java PostgreSQL JDBC driver.
 
 source $TESTLIBS
+WHOAMI=`whoami`
 TESTDIR=testdir
 PSQL=$PGBIN/psql
-export CLASSPATH=.:/usr/local/pgsql/share/postgresql-9.2-1003.jdbc4.jar
+export CLASSPATH=.:$JDBC_DRIVER
 
 rm -fr $TESTDIR
 mkdir $TESTDIR
@@ -22,18 +23,22 @@ source ./bashrc.ports
 
 export PGPORT=$PGPOOL_PORT
 
+echo "jdbc.url=jdbc:postgresql://localhost:$PGPOOL_PORT/test" > javatest.prop
+echo "jdbc.user=$WHOAMI" >> javatest.prop
+echo "jdbc.password=" >> javatest.prop
+
+
 echo "memory_cache_enabled = on" >> etc/pgpool.conf
 sh startall
 wait_for_pgpool_startup
 
-cd ..
+cp ../Sample.java .
 $PSQL test <<EOF
 DROP TABLE IF EXISTS t1;
 CREATE TABLE t1(i int);
 EOF
 javac Sample.java
 java Sample	# hang here if the bug bites you...
-cd $TESTDIR
 sh shutdownall
 exit 0
 
